import React, { Component } from 'react';
import logo from './logo.svg';
import './App.css';

import User from './components/User';
import Hobby from './components/Hobby';

import base from './base';

class App extends Component {
  constructor(props) {
    super(props);

    this.state = {
      hobbies: {
        hobby0: 'tennis',
        hobby1: 'golf'
      }
    };
  }

  addHobby() {
    // faire une copie de l'objet hobbies
    const hobbies = { ...this.state.hobbies };

    // Ajouter le nouveau hobby
    const timestamp = Date.now();
    hobbies[`hobby-${timestamp}`] = this.input.value;
    // equivalent a : hobbies['hobby' + timestamp] = this.state.input;

    // on met a jour l'etat
    this.setState({ hobbies });
    console.log(this.state.hobbies)
  }

  removeHobby(key) {
    // faire une copie de l'objet hobbies
    const hobbies = { ...this.state.hobbies };

    // Supprime le hobby dont la cle key a ete passee en parametres
    //delete hobbies[key]; // ne marche pas avec firebase
    hobbies[key] = null;

    // Mettre a jour l'etat
    // En ES6 vous pouvez juste taper {'hobbies'} au lieu de {hobbies:hobbies}
    this.setState({ hobbies });
    console.log(this.state.hobbies)
  }

  // Appele avant render
  componentWillMount() {
    console.log("Component will mount");
    this.ref = base.syncState("hobbies", {
      context: this,
      state: 'hobbies'
    });
  }

  // appele quand le composant disparait, par ex
  // quand on quitte l'application
  componentWillUnmount() {
    console.log("Component will unmount");
    base.removeBinding(this.ref);
  }

  render() {
    console.log("render");
    // iterateur sur les proprietes de l'objet  
    let list = Object.keys(this.state.hobbies).map((key, index) => {
      // key = element courant (propriete courante de l'objet)
      const hobby = this.state.hobbies[key];

      const liStyle = {
        backgroundColor: index % 2 === 0 ? 'lightpink' : 'red'
      };

      return <li key={key} style={liStyle} 
        onClick={() => this.removeHobby(key)}>
        {hobby}
        </li>
    });

    return (
      <div className="App">
        <h3>Liste des Hobbies :</h3>
        <input
          type="text"
          ref={(input) => this.input = input}
        />
        <button onClick={() => this.addHobby()}>Add Hobby</button>
        <p style={{ color: (this.state.hobbies.length < 5) ? 'green' : 'red' }}>
          Nombre de Hobbies : {Object.keys(this.state.hobbies).length}
        </p>
        <ul>
          {list}
        </ul>
      </div>
    );
  }
}

export default App;
